@@ -4,11 +4,15 @@ import shutil
 import http.server
 import concurrent.futures
 from wpwatcher.core import WPWatcher
-from wpwatcher.scan import WPWatcherScanner
-from wpwatcher.config import WPWatcherConfig
+from wpwatcher.scan import Scanner
+from wpwatcher.config import Config
+from wpwatcher.site import Site
+from wpwatcher.report import ScanReport
 from wpwatcher.utils import get_valid_filename
 from . import WP_SITES, DEFAULT_CONFIG
 
+from wpscan_out_parse.parser import WPScanJsonParser
+
 executor=None
 server=None
 class T(unittest.TestCase):
@@ -32,13 +36,13 @@ class T(unittest.TestCase):
     
     def test_update_report(self):
         # Init Scanner
-        scanner = WPWatcherScanner(WPWatcherConfig(string=DEFAULT_CONFIG).build_config()[0])
+        scanner = Scanner(Config.fromstring(DEFAULT_CONFIG))
         for s in WP_SITES:
-            old={
+            old=ScanReport({
                     "site": s['url'],
                     "status": "WARNING",
                     "datetime": "2020-04-08T16-05-16",
-                    "last_email": "2020-04-08T16-05-16",
+                    "last_email": "2020-04-08T16-05-17",
                     "error": '',
                     "infos": [
                         "[+]","blablabla"],
@@ -50,9 +54,9 @@ class T(unittest.TestCase):
                     "fixed": ["This issue was fixed"],
                     "summary":None,
                     "wpscan_output":""
-                }
-
-            new={
+                })
+            parser = WPScanJsonParser(data={})
+            new=ScanReport({
                     "site": s['url'],
                     "status": "",
                     "datetime": "2020-04-10T16-00-00",
@@ -66,38 +70,38 @@ class T(unittest.TestCase):
                     "alerts": [],
                     "fixed": [],
                     "summary":None,
+                    "wpscan_parser": parser,
                     "wpscan_output":""
-                }
+                })
 
-            expected={
+            expected=ScanReport({
                     "site": s['url'],
-                    "status": "",
+                    "status": "WARNING",
                     "datetime": "2020-04-10T16-00-00",
-                    "last_email": "2020-04-08T16-05-16",
+                    "last_email": "2020-04-08T16-05-17",
                     "error": '',
                     "infos": [
                         "[+]","blablabla"],
                     "warnings": [
-                        "[!] No WPVulnDB API Token given, as a result vulnerability data has not been output.\n[!] You can get a free API token with 50 daily requests by registering at https://wpvulndb.com/users/sign_up"
+                        "[!] No WPVulnDB API Token given, as a result vulnerability data has not been output.\n[!] You can get a free API token with 50 daily requests by registering at https://wpvulndb.com/users/sign_up\nWarning: This issue is unfixed since 2020-04-08T16-05-16"
                     ],
                     "alerts": [],
                     "fixed": [
                         "This issue was fixed",
-                        'Issue regarding component "%s" has been fixed since last report.\nLast report datetime is: %s'%("[+] WordPress version 5.2.2 identified (Insecure, released on 2019-06-18).",old['last_email'])    
+                        'Issue regarding component "%s" has been fixed since the last scan.'%("[+] WordPress version 5.2.2 identified (Insecure, released on 2019-06-18).")    
                     ],
                     "summary":None,
+                    "wpscan_parser": parser,
                     "wpscan_output":""
-                }
+                })
             
-            scanner.update_report(new,old,s)
-            print(new)
-            print(expected)
-            self.assertEqual(new, expected, "There is an issue with fixed issues feature: the expected report do not match the report returned by update_report()")
+            new.update_report(old)
+            self.assertEqual(dict(new), dict(expected), "There is an issue with fixed issues feature: the expected report do not match the report returned by update_report()")
 
     def test_wpscan_output_folder(self):
         RESULTS_FOLDER="./results/"
         WPSCAN_OUTPUT_CONFIG = DEFAULT_CONFIG+"\nwpscan_output_folder=%s"%RESULTS_FOLDER
-        scanner=WPWatcherScanner(WPWatcherConfig(string=WPSCAN_OUTPUT_CONFIG).build_config()[0])
+        scanner=Scanner(Config.fromstring(WPSCAN_OUTPUT_CONFIG))
         self.assertTrue(os.path.isdir(RESULTS_FOLDER),"WPscan results folder doesn't seem to have been init")
         for s in WP_SITES:
             report={
@@ -134,7 +138,14 @@ class T(unittest.TestCase):
 
     def test_scan_localhost_error_not_wordpress(self):
         # test info, warnings and alerts
-        scanner=WPWatcherScanner(WPWatcherConfig(string=DEFAULT_CONFIG).build_config()[0])
-        report=scanner.scan_site(WPWatcher.format_site({'url':'http://localhost:8080'}))
+        scanner=Scanner(Config.fromstring(DEFAULT_CONFIG))
+        report=scanner.scan_site(Site({'url':'http://localhost:8080'}))
         self.assertEqual(report['status'], 'ERROR')
         self.assertRegex(report['error'], 'does not seem to be running WordPress')
+
+    # def test_scan_localhost_error_not_wordpress_old_way(self):
+    #     # test info, warnings and alerts
+    #     scanner=Scanner(Config(string=DEFAULT_CONFIG).build_config()[0])
+    #     report=scanner.scan_site(Site({'url':'http://localhost:8080'}))
+    #     self.assertEqual(report['status'], 'ERROR')
+    #     self.assertRegex(report['error'], 'does not seem to be running WordPress')
